/* -*- c++ -*- */
/* 
 * Copyright (c) 2021 Satlab A/S <satlab@satlab.com>
 * 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */


#ifndef INCLUDED_SATLAB_SATLAB_SRS3_ENCRYPT_H
#define INCLUDED_SATLAB_SATLAB_SRS3_ENCRYPT_H

#include <gnuradio/satlab/api.h>
#include <gnuradio/block.h>

namespace gr {
  namespace satlab {

    /*!
     * \brief <+description of block+>
     * \ingroup satlab
     *
     */
    class SATLAB_API srs3_encrypt : virtual public gr::block
    {
     public:
      typedef std::shared_ptr<srs3_encrypt> sptr;

      /*!
       * \brief Return a shared_ptr to a new instance of satlab::srs3_encrypt.
       *
       * To avoid accidental use of raw pointers, satlab::srs3_encrypt's
       * constructor is in a private implementation
       * class. satlab::srs3_encrypt::make is the public interface for
       * creating new instances.
       */
      static sptr make(const char *key, bool encrypt, bool auth);

      virtual void set_key(const char *key) = 0;
      virtual void set_encrypt(bool encrypt) = 0;
      virtual void set_auth(bool auth) = 0;
    };

  } // namespace satlab
} // namespace gr

#endif /* INCLUDED_SATLAB_SATLAB_SRS3_ENCRYPT_H */

