/* -*- c++ -*- */
/* 
 * Copyright 2021 Satlab A/S.
 * 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */


#ifndef INCLUDED_SATLAB_WEBSOCKET_SINK_H
#define INCLUDED_SATLAB_WEBSOCKET_SINK_H

#include <gnuradio/satlab/api.h>
#include <gnuradio/sync_block.h>

namespace gr {
  namespace satlab {

    /*!
     * \brief <+description of block+>
     * \ingroup websocket
     *
     */
    class SATLAB_API websocket_sink : virtual public gr::sync_block
    {
     public:
      typedef std::shared_ptr<websocket_sink> sptr;

      /*!
       * \brief Return a shared_ptr to a new instance of websocket::websocket_sink.
       *
       * To avoid accidental use of raw pointers, websocket::websocket_sink's
       * constructor is in a private implementation
       * class. websocket::websocket_sink::make is the public interface for
       * creating new instances.
       */
      static sptr make(size_t itemsize, unsigned short port);

      virtual void set_greeting(std::string msg) = 0;
    };

  } // namespace satlab
} // namespace gr

#endif /* INCLUDED_SATLAB_WEBSOCKET_SINK_H */
