/*
 * Copyright (c) 2022 Satlab A/S <satlab@satlab.com>
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <gnuradio/io_signature.h>
#include <volk/volk.h>
#include "ber_est_impl.h"

namespace gr {
    namespace satlab {

        ber_est::sptr
        ber_est::make(int navg)
        {
            return gnuradio::get_initial_sptr
                (new ber_est_impl(navg));
        }

        int ber_est_impl::work(int noutput_items,
                               gr_vector_const_void_star& input_items,
                               gr_vector_void_star& output_items)
        {
            int navg = decimation();

            char* in0 = (char*)input_items[0];
            char* in1 = (char*)input_items[1];

            // expect navg input items per output item
            for (int i = 0; i < noutput_items; i++) {

                // count number of bit errors
                int nerrors = 0;
                for (int j = 0; j < navg; j++) {
                    if (*in0++ != *in1++)
                        nerrors++;
                }

                // we've now consumed navg samples on each input
                consume_each(navg);

                // update leve: the bit error rate
                d_level = (float)nerrors / navg;
            }

            return noutput_items;
        }

        ber_est_impl::ber_est_impl(int navg)
            : gr::sync_decimator("ber_est",
                        gr::io_signature::make(2, 2, sizeof(char)),
                        gr::io_signature::make(0, 0, 0),
                        navg),
              d_level(0)
        {}

        double ber_est_impl::level()
        {
            return d_level;
        }

    } /* namespace satlab */
} /* namespace gr */
