/* -*- c++ -*- */
/* 
 * Copyright (c) 2023 Satlab A/S <satlab@satlab.com>
 * 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <endian.h>
#include <gnuradio/io_signature.h>
#include "msg_gate_impl.h"

namespace gr {
    namespace satlab {

        msg_gate::sptr msg_gate::make()
        {
            return gnuradio::get_initial_sptr(new msg_gate_impl());
        }

        void msg_gate_impl::handle_frame(pmt::pmt_t msg)
        {
            if (!d_enabled)
                    return;

            message_port_pub(pmt::mp("out"), msg);
        }

        void msg_gate_impl::set_enabled(bool enabled)
        {
            d_enabled = enabled;
        }

        msg_gate_impl::msg_gate_impl()
            : gr::block("msg_gate",
                    gr::io_signature::make(0, 0, 0),
                    gr::io_signature::make(0, 0, 0)),
            d_enabled(true)
        {
            message_port_register_out(pmt::mp("out"));

            message_port_register_in(pmt::mp("in"));
            set_msg_handler(pmt::mp("in"), [this](pmt::pmt_t msg) {
                this->handle_frame(msg);
            });
        }
    } /* namespace satlab */
} /* namespace gr */
