/* 
 * Copyright (c) 2021 Satlab A/S <satlab@satlab.com>
 * 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_SATLAB_PHASE_STEPPER_IMPL_H
#define INCLUDED_SATLAB_PHASE_STEPPER_IMPL_H

#include <gnuradio/satlab/api.h>
#include <gnuradio/satlab/phase_stepper.h>

namespace gr {
    namespace satlab {

        class SATLAB_API phase_stepper_impl : public phase_stepper
        {
            private:
                gr_complex d_phase;
		float d_step_size;
                uint64_t d_timeout_samples;
                uint64_t d_last_kick;
                void kick(void);
                void handle_kick(pmt::pmt_t pdu);

            public:
                phase_stepper_impl(uint64_t timeout_samples, float step_size);

                void set_timeout(uint64_t samples);

                int work(int noutput_items,
                        gr_vector_const_void_star& input_items,
                        gr_vector_void_star& output_items);
        };

    } /* namespace satlab */
} /* namespace gr */

#endif /* INCLUDED_SATLAB_PHASE_STEPPER_IMPL_H */
