/*
 * Copyright 2021 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#include <pybind11/complex.h>
#include <pybind11/pybind11.h>
#include <pybind11/stl.h>

namespace py = pybind11;

#include <gnuradio/satlab/phase_stepper.h>
// pydoc.h is automatically generated in the build directory
#include <phase_stepper_pydoc.h>

void bind_phase_stepper(py::module& m)
{
    using phase_stepper = ::gr::satlab::phase_stepper;

    py::class_<phase_stepper,
               gr::sync_block,
               gr::block,
               gr::basic_block,
               std::shared_ptr<phase_stepper>>(m, "phase_stepper", D(phase_stepper))

        .def(py::init(&phase_stepper::make),
            py::arg("timeout_samples"),
            py::arg("step_size"),
            D(phase_stepper, make)
        )

        .def("set_timeout",
            &phase_stepper::set_timeout,
            py::arg("samples"),
            D(phase_stepper, set_timeout)
        );
}
