/*
 * Copyright 2020 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#include <pybind11/pybind11.h>

#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
#include <numpy/arrayobject.h>

namespace py = pybind11;

void bind_correlate_access_code_tag_fixed(py::module& m);
void bind_idle_frame_gen(py::module& m);
void bind_msg_gate(py::module& m);
void bind_phase_stepper(py::module& m);
void bind_node_sync(py::module& m);
void bind_snr_est(py::module& m);
void bind_ber_est(py::module& m);
void bind_srs3_decode(py::module& m);
void bind_srs3_decrypt(py::module& m);
void bind_srs3_deframe(py::module& m);
void bind_srs3_encode(py::module& m);
void bind_srs3_encrypt(py::module& m);
void bind_srs3_enframe(py::module& m);
void bind_tag_to_trigger(py::module& m);
void bind_websocket_sink(py::module& m);

// We need this hack because import_array() returns NULL
// for newer Python versions.
// This function is also necessary because it ensures access to the C API
// and removes a warning.
void* init_numpy()
{
    import_array();
    return NULL;
}

PYBIND11_MODULE(satlab_python, m)
{
    // Initialize the numpy C API
    // (otherwise we will see segmentation faults)
    init_numpy();

    // Allow access to base block methods
    py::module::import("gnuradio.gr");

    bind_correlate_access_code_tag_fixed(m);
    bind_idle_frame_gen(m);
    bind_msg_gate(m);
    bind_phase_stepper(m);
    bind_node_sync(m);
    bind_snr_est(m);
    bind_ber_est(m);
    bind_srs3_decode(m);
    bind_srs3_decrypt(m);
    bind_srs3_deframe(m);
    bind_srs3_encode(m);
    bind_srs3_encrypt(m);
    bind_srs3_enframe(m);
    bind_tag_to_trigger(m);
#ifdef ENABLE_WEBSOCKET
    bind_websocket_sink(m);
#endif
}
